#
# spec file for package libusbmuxd
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libusbmuxd-2_0-6
Name:           libusbmuxd
Version:        2.0.2
Release:        1.12
Summary:        A client library to multiplex connections from and to iOS devices
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
URL:            https://github.com/libimobiledevice/libusbmuxd
Source:         https://github.com/libimobiledevice/libusbmuxd/archive/%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libplist-2.0) >= 2.2.0

%description
'usbmuxd' stands for "USB multiplexing daemon". This daemon is in charge of
multiplexing connections over USB to an iPhone or iPod touch. To users, it means
you can sync your music, contacts, photos, etc. over USB. To developers, it
means you can connect to any listening localhost socket on the device. usbmuxd
is not used for tethering data transfer, which uses a dedicated USB interface as
a virtual network device.

This package contains the usbmuxd communication interface library 'libusbmuxd'.

%package -n %{libname}
Summary:        A client library to multiplex connections from and to iOS devices
Recommends:     usbmuxd
Provides:       libusbmuxd6 = %{version}
Obsoletes:      libusbmuxd6 < %{version}

%description -n %{libname}
'usbmuxd' stands for "USB multiplexing daemon". This daemon is in charge of
multiplexing connections over USB to an iPhone or iPod touch. To users, it means
you can sync your music, contacts, photos, etc. over USB. To developers, it
means you can connect to any listening localhost socket on the device. usbmuxd
is not used for tethering data transfer, which uses a dedicated USB interface as
a virtual network device.

This package contains the usbmuxd communication interface library 'libusbmuxd'.

%package devel
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}

%description devel
'usbmuxd' stands for "USB multiplexing daemon". This daemon is in charge of
multiplexing connections over USB to an iPhone or iPod touch. To users, it means
you can sync your music, contacts, photos, etc. over USB. To developers, it
means you can connect to any listening localhost socket on the device. usbmuxd
is not used for tethering data transfer, which uses a dedicated USB interface as
a virtual network device.

The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary:        An example tools to forward localhost ports to iOS devices
Provides:       iproxy = %{version}
Obsoletes:      iproxy < %{version}

%description tools
'usbmuxd' stands for "USB multiplexing daemon". This daemon is in charge of
multiplexing connections over USB to an iPhone or iPod touch. To users, it means
you can sync your music, contacts, photos, etc. over USB. To developers, it
means you can connect to any listening localhost socket on the device. usbmuxd
is not used for tethering data transfer, which uses a dedicated USB interface as
a virtual network device.

Multiple connections to different TCP ports can happen in parallel. An example
(and useful) tool called 'iproxy' is included that allows you to forward
localhost ports to the device---allows SSH over USB on jailbroken devices, or
allowing access the lockdown daemon (and then to all of the file access, sync,
notification and backup services running on the device).

%prep
%setup -q

%build
autoreconf -fvi
export CFLAGS="%{optflags} -fexceptions"
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc AUTHORS README.md
%{_libdir}/libusbmuxd-2.0.so.*

%files devel
%{_includedir}/usbmuxd.h
%{_includedir}/usbmuxd-proto.h
%{_libdir}/libusbmuxd-2.0.so
%{_libdir}/pkgconfig/%{name}-2.0.pc

%files tools
%{_bindir}/iproxy
%{_bindir}/inetcat
%{_mandir}/man1/inetcat.1%{?ext_man}
%{_mandir}/man1/iproxy.1%{?ext_man}

%changelog
* Sun Nov  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update baselibs.conf
* Mon Sep 21 2020 Stefan Elser <suse@foomaster.de>
- Update to 2.0.2:
  - Handle USB and network devices with new options in tools
  - Make connecting sockets non-blocking
  - Rename library and all related files by adding an API version resulting in libusbmuxd-2.0
  - Allow to specify source address for listening socket in iproxy
  - Allow to map multiple ports in iproxy
  - Lots of bug fixes and other improvements
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
  - Add proper support for USB and network (WiFi sync) devices reported by usbmuxd
  - Add new usbmuxd_events_subscribe/unsubscribe functions with a context so it can be used in different threads
  - Add new tool 'icat'
  - Lots of bug fixes and other improvements
  - Rename 'icat' tool to 'inetcat' due to name conflict with sleuthkit's icat
- Remove merged patch libusbmuxd-CVE-2016-5104.patch
* Thu Jan 23 2020 Cristian Rodríguez <crrodriguez@opensuse.org>
- Software using pthread_cleanup_* routines must be built with
  with -fexceptions so a safer and cleaner implementation is
  used.
* Mon Oct  2 2017 jengelh@inai.de
- Rectify RPM groups.
* Fri Sep 22 2017 fcrozat@suse.com
- Use a macro for specifying library major
- Recommends usbmuxd to library package to ensure it works
  properly.
- Remove duplicated dependency on iproxy subpackage.
* Fri May 27 2016 dimstar@opensuse.org
- Add libusbmuxd-CVE-2016-5104.patch: Make sure sockets only
  listen locally (CVE-2016-5104, boo#982014).
* Mon Feb 22 2016 mgorse@suse.com
- Add COPYING to %%doc
* Fri Oct 17 2014 m.szulecki@libimobiledevice.org
- Update to version 1.0.10
  * Retry to connect to usbmuxd socket if first attempt failed (Linux/inotify)
  * Avoid exporting non-public symbols
  * Allow multiple connections to iproxy listen port
  * Add ability to target device by UDID to iproxy
  * Remove outdated/unmaintained Python and sftp examples
  * Update README and rename license to more generic COPYING
  * Rename header guards according to C++ standard
  * Fix a few crashes related to using old usbmuxd daemon and broken pair
  * records
  * Fix out of tree build
  * Fix leaking socket handles by properly closing them
  * Check for validity of socket file descriptor
  * Properly handle segmented send/receive situations to improve reliability
* Thu Jul 10 2014 i@marguerite.su
- clean specfile as DimStar suggested
* Mon Jun 16 2014 i@marguerite.su
- initial version 1.0.9
